@@ -217,11 +217,22 @@ void LogFile_Action(ZenLib::Ztring Inform)
         return;
 
     std::string Inform_Ansi=Inform.To_UTF8();
-    std::fstream File(LogFile_FileName.To_Local().c_str(), std::ios_base::out|std::ios_base::binary|std::ios_base::trunc);
+    std::fstream File(LogFile_FileName.To_Local().c_str(), std::ios_base::out|std::ios_base::trunc);
     #if defined(_MSC_VER) && defined(UNICODE)
         if (CLI_Option_Bom)
             File.write("\xEF\xBB\xBF", 3);
     #endif //defined(_MSC_VER) && defined(UNICODE)
     File.write(Inform_Ansi.c_str(), Inform_Ansi.size());
 }
+void CallBack_Set(Core &MI, void* Event_CallBackFunction)
+{
+    //CallBack configuration
+    #if defined(UNICODE)
+        std::wostringstream Event_CallBackFunction_Text;
+    #else
+        std::ostringstream Event_CallBackFunction_Text;
+    #endif
+    Event_CallBackFunction_Text<<"CallBack=memory://"<<(size_t)Event_CallBackFunction;
+    MI.Menu_Option_Preferences_Option(_T("Event_CallBackFunction"), Event_CallBackFunction_Text.str());
+}
 
